import classNames from 'classnames';
import React, { useEffect, useState } from 'react';
import { withNativeProps } from '../../utils/native-props';
import { useNewControllableValue } from '../../utils/use-controllable-value';
import { withDefaultProps } from '../../utils/with-default-props';
import { bound } from '../../utils/bound';
var classPrefix = "adm-stepper";
var defaultProps = {
  defaultValue: 0,
  step: 1,
  disabled: false
};
export var Stepper = withDefaultProps(defaultProps)(function (props) {
  var _classNames;

  var disabled = props.disabled,
      step = props.step,
      max = props.max,
      min = props.min;

  var _useNewControllableVa = useNewControllableValue(props),
      value = _useNewControllableVa[0],
      setValue = _useNewControllableVa[1];

  var _useState = useState(function () {
    return value.toString();
  }),
      inputValue = _useState[0],
      setInputValue = _useState[1];

  function setValueWithCheck(v) {
    if (isNaN(v)) return;
    var target = bound(v, props.min, props.max);

    if (props.digits || props.digits === 0) {
      target = parseFloat(target.toFixed(props.digits));
    }

    setValue(target);

    if (!hasFocus) {
      setInputValue(target.toString());
    }
  }

  var _useState2 = useState(false),
      hasFocus = _useState2[0],
      setHasFocus = _useState2[1];

  useEffect(function () {
    if (!hasFocus) {
      setInputValue(value.toString());
    }
  }, [hasFocus]);

  var handleInputChange = function handleInputChange(v) {
    setInputValue(v);
    setValueWithCheck(parseFloat(v));
  };

  var handleMinus = function handleMinus() {
    setValueWithCheck(value - step);
  };

  var handlePlus = function handlePlus() {
    setValueWithCheck(value + step);
  };

  var minusDisabled = function minusDisabled() {
    if (min === undefined) {
      return disabled;
    } else {
      return disabled || value <= min;
    }
  };

  var plusDisabled = function plusDisabled() {
    if (max === undefined) {
      return disabled;
    } else {
      return disabled || value >= max;
    }
  };

  return withNativeProps(props, /*#__PURE__*/React.createElement("div", {
    className: classNames(classPrefix, (_classNames = {}, _classNames[classPrefix + "-disabled"] = disabled, _classNames))
  }, /*#__PURE__*/React.createElement("button", {
    type: 'button',
    className: classPrefix + "-minus",
    onClick: handleMinus,
    disabled: minusDisabled()
  }), /*#__PURE__*/React.createElement("input", {
    onFocus: function onFocus() {
      setHasFocus(true);
    },
    value: inputValue,
    onChange: function onChange(e) {
      disabled || handleInputChange(e.target.value);
    },
    disabled: disabled,
    onBlur: function onBlur() {
      setHasFocus(false);
    }
  }), /*#__PURE__*/React.createElement("button", {
    type: 'button',
    className: classPrefix + "-plus",
    onClick: handlePlus,
    disabled: plusDisabled()
  })));
});